#
# spec file for package gridcoin
#
# Copyright (c) 2014-2015 Matthias Bach <marix@marix.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

## `make check` fails otherwise
##undefine _hardened_build
##undefine _annotated_build

# Qt5 in (RHEL || CentOS) <=7 is too old
%if 0%{?rhel} && 0%{?rhel} <= 7
%bcond_with gui
%global buildargs --with-gui=no
%else
%bcond_without gui
%endif

%global _gh_name Gridcoin-Research
Name:           gridcoinresearch
Version:        4.0.1.0
Release:        1%{?dist}
Summary:        P2P Digital Currency
License:        MIT
%if 0%{?suse_version}
Group:          Productivity/Networking/Other
%endif
Url:            http://www.gridcoin.us
Source0:        https://github.com/gridcoin-community/%{_gh_name}/archive/%{version}.tar.gz
Source1:        %{name}-qt.desktop
BuildRequires:  unzip
%if 0%{?suse_version} >= 1500
BuildRequires:  libboost_filesystem-devel
BuildRequires:  libboost_program_options-devel
BuildRequires:  libboost_system-devel
BuildRequires:  libboost_thread-devel
%else
BuildRequires:  boost-devel
%endif
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
# Dunno what for actually
BuildRequires:  git
BuildRequires:  gcc-c++
BuildRequires:  openssl-devel
%if 0%{?suse_version}
BuildRequires:  libdb-cxx-devel
%else
BuildRequires:  libdb4-cxx-devel
%endif
BuildRequires:  miniupnpc-devel
BuildRequires:  protobuf-devel
%if 0%{with gui}
BuildRequires:  qrencode-devel
BuildRequires:  qt5-qtbase-devel
%if 0%{?suse_version} > 1320 || 0%{?fedora} >= 27
BuildRequires:  qt5-qtcharts-devel
%endif
BuildRequires:  qt5-linguist
BuildRequires:  desktop-file-utils
%endif
BuildRequires:  icoutils
BuildRequires:  libzip-devel
BuildRequires:  libcurl-devel
%{?systemd_requires}
BuildRequires:  systemd
%{?suse_version:Recommends:     boinc-client}

%description
Gridcoin is an open source peer-to-peer cryptocurrency using a BOINC based Proof
of Research instead of the more common Proof of Work for block generation.

%global daemonname %{name}d
%package -n %{daemonname}

Summary:        Headless daemon for the Gridcoin crypto-currency
License:        MIT
%if 0%{?suse_version}
Group:          Productivity/Networking/Other
%endif

%description -n %{daemonname}
Gridcoin is an open source peer-to-peer cryptocurrency using a BOINC based Proof
of Research instead of the more common Proof of Work for block generation

This package provides gridcoinresearchd, headless gridcoin daemon.

%if %{with gui}
%package qt

Summary:        An end-user Qt GUI for the Gridcoin crypto-currency
License:        MIT
%if 0%{?suse_version}
Group:          Productivity/Networking/Other
%endif

%description qt
Gridcoin is an open source peer-to-peer cryptocurrency using a BOINC based Proof
of Research instead of the more common Proof of Work for block generation

This package provides gridcoinresearch, a GUI for Gridcoin based on Qt.
%endif

%prep
%setup -q -n %{_gh_name}-%{version}

%build
./autogen.sh
%configure --disable-tests %{?buildargs}
make %{?_smp_mflags}
%if %{with gui}
icotool -x -o %{name}.png -i 1 src/qt/res/icons/gridcoin.ico
%endif

%install
%make_install

# systemd stuff
mkdir -p %{buildroot}%{_tmpfilesdir}
cat <<EOF > %{buildroot}%{_tmpfilesdir}/%{daemonname}.conf
d /run/%{daemonname} 0750 %{daemonname} %{daemonname} -
EOF
touch -a -m -t 201504280000 %{buildroot}%{_tmpfilesdir}/%{daemonname}.conf

mkdir -p %{buildroot}%{_sysconfdir}/sysconfig
cat <<EOF > %{buildroot}%{_sysconfdir}/sysconfig/%{daemonname}
# Provide options to the %{daemonname} daemon here, for example
# OPTIONS="-testnet -disable-wallet"

OPTIONS=""

# System service defaults.
# Don't change these unless you know what you're doing.
CONFIG_FILE="%{_sysconfdir}/%{daemonname}/%{daemonname}.conf"
DATA_DIR="%{_localstatedir}/lib/%{daemonname}"
PID_FILE="/run/%{daemonname}/%{daemonname}.pid"
EOF
touch -a -m -t 201504280000 %{buildroot}%{_sysconfdir}/sysconfig/%{daemonname}

mkdir -p %{buildroot}%{_unitdir}
cat <<EOF > %{buildroot}%{_unitdir}/%{daemonname}.service
[Unit]
Description=TokyoCoin daemon
After=syslog.target network-online.target

[Service]
Type=forking
ExecStart=%{_sbindir}/%{daemonname} -daemon -conf=\${CONFIG_FILE} -datadir=\${DATA_DIR} -pid=\${PID_FILE} \$OPTIONS
EnvironmentFile=%{_sysconfdir}/sysconfig/%{daemonname}
User=%{daemonname}
Group=%{daemonname}

Restart=on-failure
PrivateTmp=true
TimeoutStopSec=120
TimeoutStartSec=60
StartLimitInterval=240
StartLimitBurst=5

[Install]
WantedBy=multi-user.target
EOF
touch -a -m -t 201504280000 %{buildroot}%{_unitdir}/%{daemonname}.service
#end systemd stuff

%if %{with gui}
install -D -m 0644 %{name}.png %{buildroot}%{_datadir}/pixmaps/%{name}.png
%if 0%{?suse_version}
  install -D -m 0644 %{SOURCE1} %{buildroot}%{_datadir}/applications/%{name}-qt.desktop
  %suse_update_desktop_file %{name}-qt
%else
  # Assume Red Hat-like distribution
  desktop-file-install --dir=${RPM_BUILD_ROOT}%{_datadir}/applications %{SOURCE1}
%endif
%endif

# Install man-pages
install -D -m 0644 doc/%{daemonname}.1 %{buildroot}%{_mandir}/man1/%{daemonname}.1
%if %{with gui}
install -D -m 0644 doc/%{name}.1 %{buildroot}%{_mandir}/man1/%{name}.1
%endif

##check
#make check %{?_smp_mflags}

%pre -n %{daemonname}
getent group %{daemonname} >/dev/null || groupadd -r %{daemonname}
getent passwd %{daemonname} >/dev/null ||
        useradd -r -g %{daemonname} -d /var/lib/%{daemonname} -s /sbin/nologin \
        -c "Gridcoin wallet server" %{daemonname}
exit 0

%post -n %{daemonname}
%systemd_post %{daemonname}.service

%preun -n %{daemonname}
%systemd_preun %{daemonname}.service

%postun -n %{daemonname}
%systemd_postun_with_restart %{daemonname}.service

%if %{with gui} && 0%{?suse_version} && 0%{?suse_version} < 1330
%post qt
%desktop_database_post

%postun qt
%desktop_database_postun
%endif

%files -n %{daemonname}
%{_bindir}/%{daemonname}
%{_mandir}/man1/%{daemonname}.1*
%{_tmpfilesdir}/%{daemonname}.conf
%{_unitdir}/%{daemonname}.service
%attr(0640,%{daemonname},%{daemonname}) %{_sysconfdir}/sysconfig/%{daemonname}

%if %{with gui}
%files qt
%{_bindir}/%{name}
%{_datadir}/applications/%{name}-qt.desktop
%{_datadir}/pixmaps/%{name}.png
%{_mandir}/man1/%{name}.1*
%endif

%changelog
* Wed Mar 06 2019 Vadim Raskhozhev <iamdexpl@gmail.com> - 4.0.1.0-1
- New version

* Mon Sep 10 2018 Vadim Raskhozhev <iamdexpl@gmail.com> - 3.7.15.0-3
- Removed "BuildRoot" and "%%defattr" cruft
- Disabled GUI build on (RHEL || CentOS) <=7 (its qt5 way too old)
* Mon Sep 03 2018 Vadim Raskhozhev <iamdexpl@gmail.com> - 3.7.15.0-2
- Added a separate user to run the daemon as
- Added systemd stuff
* Sat Sep 01 2018 Vadim Raskhozhev <iamdexpl@gmail.com> - 3.7.15.0-1
- install section replaced with `make_install`
- New version
* Fri Mar 16 2018 marix@marix.org
- Update to version 3.7.11.0.375a78e6a:
  * Fix wallet being locked while flushing. It now requires a clean
    shutdown or a backup to migrate the wallet.dat to a different
    system.
  * Automatic backups can now be disabled by using
    `-walletbackupinterval=0`.
  * Trigger a fix spent coins check on start and after block
    disconnect.
* Mon Mar  5 2018 marix@marix.org
- Update to version 3.7.10.0.250d96a5c:
  * Fix sync issues due to beacon age checks.
* Sat Mar  3 2018 marix@marix.org
- Update to version 3.7.9.0.335739542:
  * Fix stray data in beaconreport RPC.
* Thu Mar  1 2018 marix@marix.org
- Update to version 3.7.8.0.3ffccdb10:
  * Check incoming blocks for malformed DPoR signature.
  * Corect tally height on init.
  * Prevent staking of a block with a failed signature.
  * Fix UI and RPC slowdown regression.
  * Fix fork issue due to research age calculation inconsistencies.
  * Fix crashes when tallying.
  * Fix sync issues with incorrectly accepted v8 beacons.
  * Don't tally until V9 to speed up syncing.
* Sat Feb  3 2018 marix@marix.org
- Update to version 3.7.7.0.d3c0eb952:
  * Beacon validation is now done when accepting blocks, not when
    receiving.
  * Fix crashes due to buffer overflow in encrypt/decrypt.
  * Rewrite reorganize routine to be more reliable and drop
    contracts received or issued while on a side chain to help
    reducing forks.
* Thu Jan 25 2018 marix@marix.org
- Update to version 3.7.5.0.8a6432e5a:
  * Fix crash when switching to new tally on block 1144120.
  * Fix crash when staking while tallying.
* Wed Jan 24 2018 marix@marix.org
- Update to version 3.7.4.0.dc8b888af:
  * Fix RPC resource leak regression.
  * Fix incorrect return code when running in the background.
* Sat Jan 13 2018 marix@marix.org
- Update to version 3.7.3.0.375301041:
  * Fix for wallet not daemonizing.
  * Fix for UI getting stuck in splash screen.
* Fri Jan 12 2018 marix@marix.org
- Update to version 3.7.1.0.2a6a538e7:
  * Fix several crashes in diagnostic dialog.
  * Fix client not exiting when running as daemon.
  * Update splash screen.
- Update the icon used for the desktop entry.
- Remove download service in favour of tar_scm service run only on demand.
* Thu Jan 11 2018 marix@marix.org
- Fix build on Tumbleweed
* Wed Jan 10 2018 marix@marix.org
- Udpate to version 3.7.0.0
  + Mandatory Upgrade
  + Provide Difficulty of best kernel found
  + Add better command for sending alerts
  + Add RPC for sending raw contracts
  + Add portable diagnostic page
  + Several tally improvements. There should now be less forking and the wallet should use ~50MB less memory
  + Remove CSV exporter which used unreliable data
  + Removed RPC commands (@Foggyx420, @denravonska):
  * debugexplainmagnitude
  * executecode
  * getsubsidy
  * list newbieage
  * list staking
  * leder
  * reboot
  + Remove IRC peer discovery
* Tue Oct 10 2017 marix@marix.org
- Udpate to version 3.6.3.0
  + Fix clients getting stuck at V8 blocks when syncing.
* Mon Oct  2 2017 marix@marix.org
- Update to version 3.6.2.0.
  + Add "backupprivatekeys" RPC command.
  + Reduce startup time.
  + Prevent email being leaked in CPIDv2 block field.
  + Fix memory leaks.
- Remove fix-upgrader-compilation.patch now included upstream.
* Wed Sep 13 2017 marix@marix.org
- Update to version 3.6.1.0.
  + Fix problems forging superblock due to rounding differences.
  + Fetch data from project servers if missing on scraper.
* Mon Aug 28 2017 marix@marix.org
- Add missing dependencies for Tumbleweed and Factory
* Mon Aug 28 2017 marix@marix.org
- Update to version 3.6.0.2
  + Mandatory Upgrade
  + Fix incorrect V8 height trigger check
* Thu Aug 24 2017 marix@marix.org
- Remove dependencies added for Factory as the cannot be resolved
  and break Tumbleweed which otherwise works.
* Thu Aug 24 2017 marix@marix.org
- Update to version 3.6.0.1
  + Mandatory Upgrade
  + V8 Stake Engine
  + Memory allocation fix for syncing from 0
  + Tray Icon
  + Fix startup crash for new users
- Add patch fix-upgrader-compilation.patch.
- Add missing dependencies for Factory.
* Sat Aug  5 2017 marix@marix.org
- Update to version 3.5.9.9
  + Fixed multiple bugs causing hangs, crashed and high CPU load.
  + Improved translations.
  + Removed obsolete functionality.
* Sun Jul 30 2017 marix@marix.org
- Update to version 3.5.9.8
  + Revised Neural Network business logic rule fix inability to
    stake current superblock
  + Revised Neural Network magnitude calculation to prevent
    diluted magnitudes
* Tue Jul 25 2017 marix@marix.org
- Update to version 3.5.9.7b
  + Neural Network business logic rule fix inability to stake
    current superblock
* Sun Jul 23 2017 marix@marix.org
- Update to version 3.5.9.5a
  + Fixed Neural Network handling of 404 errors (causing incomplete
    superblocks), and bug causing it to skip Rosetta
* Sun Jul 16 2017 marix@marix.org
- Update to version 3.5.9.4
  + Fix neural network inability to stake superblocks
  + Require superblocks to be populated with more than half of the
    whitelisted projects
  + Add subfolders to Neural Network
* Wed Jul  5 2017 marix@marix.org
- Update to version 3.5.9.2
  + Fix neural network project gather bug related to timezones
* Tue Jul  4 2017 marix@marix.org
- Update to version 3.5.9.1
  + Prevent untauthorized poll and vote deletions
  + Neural network improvements
* Tue Jun 13 2017 marix@marix.org
- Fix build on Fedora
* Tue Jun 13 2017 marix@marix.org
- Use Qt5 instead of Qt4
* Tue Jun  6 2017 marix@marix.org
- Update to version 3.5.9.0
  + Added execute unspentreport (shows proof of unspent coins in
    wallet).
  + Add RPC commands for changing debug flags: debug, debugnet,
    debug2, debug3, debug4, debug5, debug10.
  + Upgraded security on voting system.
  + Translation updates
  + Removed empty "wcgtest" RPC command.
  + Fixed numerous beacon issues.
* Mon May 15 2017 marix@marix.org
- Update to version 3.5.8.9
  + Reduced memory usage by around 100MB+. Optimize released
    resources.
  + Make client readvertise beacon using existing keypair after 5
    months
  + Implement voting functionality for Linux
  + Update translations: Hungarian, Portuguese
  + update Gridcoin icons
  + Change splash screen
  + Windows are now resizable
  + Improve UI when used with dark themes on Linux
  + Fix occasional crashes when starting on Linux
  + Fix freeze when clicking on the "Amount" field under Send Coins
    when using KDE
  + Add manpages
- Remove custom man pages in favour of upstream ones.
* Tue Apr  4 2017 marix@marix.org
- Update to version 3.5.8.8b
  + Mandatory Upgrade
  + Fix announced client version.
* Sun Apr  2 2017 marix@marix.org
- Update to version 3.5.8.8
  + Mandatory Upgrade
  + Resolve syncing problem with beacon business logic.
* Mon Mar 27 2017 marix@marix.org
- Update to version 3.5.8.7
  + Mandatory Upgrade, enforced after block 855000.
  + Enforce beacon age; beacons over 6 months are discarded network
    wide. Beacons may be re-sent without restarting if they are
    expired.
  + For a faster sync issue the following command:
    gridcoinupgrader downloadblocks
* Mon Feb 13 2017 marix@marix.org
- Update to version 3.5.8.6
  * CPID verification and handling no longer depends on Netsoft
  * 'execute proveownership' now work in a decentralized fashion
* Sun Jan  1 2017 marix@marix.org
- Update to version 3.5.8.4
  + Leisure Upgrade
  + Lower CPU usage
  + Fix HTTP error on diagnostics page
  + Add checkpoints up till block 770000.
  + Removed unused functionality
* Tue Nov 22 2016 marix@marix.org
- Update to version 3.5.8.3
  + Leisure Upgrade
  + Lower memory consumption
  + Avoid UI blocks
  + Changed magnitude vote weight to
    Total Money Supply / 5.67 * Magnitude
* Sat Nov  5 2016 marix@marix.org
- Update to version 3.5.8.2
  + Leisure Upgrade
  + At block 725000 we require blocks to be signed with keypairs.
  + Enable binary superblocks at block 725000.
- Add basic man pages
* Sun Oct 16 2016 marix@marix.org
- Update to version 3.5.8.1
  + Leisure Upgrade
  + Added Configuration File backup into the nightly Wallet Backup
    process (the file is stored in /walletbackups).
  + Added a suffix to the keypair configuration key name for
    TESTNET only (PROD has no suffix).
    NOTE: Anyone who has a Testnet Keypair that is already set up,
    please add the testnet suffix to your keypair name like this:
    publickeyCPIDtestnet=
    (otherwise you will see errors in execute beaconstatus)
  + Added more error messages to execute beaconstatus to detect
    configuration problems.
* Mon Oct  3 2016 marix@marix.org
- Update to version 3.5.8.0
  + Leisure Upgrade
  + Mandatory Upgrade for Testnet
  + From block 195500 in TestNet, POR are required to be signed
    with the CPID private key
  + Added 'list magnitude CPID*' where CPID* is Part of your cpid,
    for example if your cpid starts with 784, list magnitude 784
    will show the magnitude for that CPID as of the
    last superblock.
  + Fixed problem where the chain rolls back to the next mandatory
    block cutover in testnet.
  + Added patch to store 0 or 1 in nContract field (please test
    after block 196550)
* Wed Sep 28 2016 marix@marix.org
- Update to version 3.5.7.9
  + Leisure Upgrade
  + Mandatory Upgrade for Testnet
  + Fixed log spam in testnet
* Mon Sep 26 2016 marix@marix.org
- Update to version 3.5.7.8
  + Leisure Upgrade
  + Mandatory Upgrade for Testnet
  + From block 195500 in TestNet, POR are required to be signed
    with the CPID private key
* Sun Sep 18 2016 marix@marix.org
- Update to version 3.5.7.7
  + Leisure Upgrade
  + Added 'execute upgradedbeaconreport' (Shows %% of users using
    the upgraded beacons)
  + Added v2 Beacons (beacons with Public and Private keypairs)
  + Modified execute advertisebeacon (to use keypairs)
  + Added beacon public key to beacon, block and block signing
    process
  + Added public key and beacon key validity to showblock/getblock
  + Added execute beaconstatus (shows the status of the beacon)
  + Added execute proveownership (shows proof-of-ownership of the
    cpid)
* Mon Aug 29 2016 marix@marix.org
- Update to version 3.5.7.6
  + Leisure Upgrade
  + Voting System:
    a. Allow up to 40 answers to be charted (fixes UI error)
    b. Chart voting results as a pie chart (so we can see results
    for large answersets)
    c. Clear up overlapping chart labels, Fixed voting list column
    widths
    e. Fixed Balance Voting Weight to include wallet total coins
    owned (regardless of stake bucket amount)
  + Load Speed:
    a. Show blocks loaded progress on splash screen
    b. Load time has been improved
  + Fix data storage bug for block.iscontract=1, (this will speed
    up the load time in the future)
  + Updated Chat Room Link
  + Added Reward Sharing feature. When
    RS=GridcoinRewardSharingAddress is populated (in the config),
    10%% of the POR reward is sent to the reward sharing address.
* Sun Aug 14 2016 marix@marix.org
- Update to version 3.5.7.4
  + Leisure Upgrade
  + Fix crash on startup when client has no blocks file.
* Fri Aug 12 2016 marix@marix.org
- Update to version 3.5.7.3b
  + Leisure Upgrade
  + Reduced log noise
  + Various sync improvements for clients syncing from 0, and for
    getblocks for nodes already in sync
  + Added rpc command: execute sendblock blockhash (for debugging)
  + Added rpc command: execute askforoutstandingblocks (for
    debugging)
* Tue Aug  9 2016 marix@marix.org
- Update to version 3.5.7.2
  + Leisure Upgrade
  + Fix Sync issues and Orphan issues
* Mon Jul 25 2016 marix@marix.org
- Update to version 3.5.7.1
  + Leisure Upgrade
  + Verify code does not restart client during initial syncing
  + Bubble error handler messagebox while submitting expense
  + Fixed GRCRestarter block downloader percentage value (where it
    could exceed 100%%).
  + Block Syncing: Fixed a long standing bug where the wallet
    randomly stops asking for the best block. Additionally, when
    out of sync it will  ask for missing blocks periodically.
    Made wallet more aware of clusters of orphans.
  + Modified getmininginfo and overview for Investors to say
    Staking Interest (instead of Boinc Mining) and removed Boinc
    Projects Exhaused for Investors. Removed Unable To Mine
    message for Investors.
  + Moved unecessary logging to fDebug10=true.  Added message to
    show the condition when Process Block succeeds and Set Best
    Chain fails.
  + Added execute askforoutstandingblocks for debugging.
* Mon Jul 11 2016 marix@marix.org
- Update to version 3.5.6.8
  + Leisure Upgrade
  + Refactored Sync/Recover code to sync properly and prevent
    wallet from crashing or hanging
* Tue Jun 14 2016 marix@marix.org
- Update to version 3.5.6.7
  + Leisure Upgrade
  + Syncing: Modified sync approach to detect ghost chains, missing
    superblocks or out-of-sync-by-age conditions, and now the
    wallet should recover automatically if it stays out of sync for
    30+ minutes.
  + Removed GRCAddress from getpeerinfo
* Mon Jun  6 2016 marix@marix.org
- Update to version 3.5.6.5
  + Leisure Upgrade
  + Modify business logic for superblock to allow superblock to be
    accepted with a lower Project average.
* Tue May 17 2016 marix@marix.org
- Update to version 3.5.6.4
  + Leisure Upgrade
  + Fix neural network: ensure RAC timestamps are current and
    synced within 24 hours. Reduce size of master database by
    filtering unecessary rows.
  + Remove potential database memory leak
  + Add watchonly support.
  + Added code to keep the node in sync. Periodically, if the
    client falls out of sync for more then 30 minutes, the client
    asks other nodes for blocks, clears orphans, clears ban flags,
    reconnects to the network, reloads the chain and resyncs.
  + Added execute recover (this manually attempts to recover).
  + Moved Surpassed max inbound connections to (debug=true) to
    remove spam from the logs.
  + Add hex support to getrawtransaction for coinvault.io.
* Sat Apr 23 2016 marix@marix.org
- Update to version 3.5.6.3/317
  + Leisure Upgrade
  + More efficiencies for neural network
  + Added data support for Derp. Modified createrawtransaction to
    support data + rawdata.
  + Fixed incorrect sRGB profiles
* Sun Apr 17 2016 marix@marix.org
- Update to version 3.5.6.1/317
  + Leisure Upgrade
  + Make the neural network honor the datadir key
  + Add more efficiency to the neural network after supermajority
    agreement occurs
  + Add support for OP Return codes
  + Socket message for empee584 (github)
  + Added new config keys: windowwidth=984 and windowheight=550.
    If necessary, make these values larger for certain high DPI
    displays.
  + Removed last payment date field on overview and Number of
    Transactions (not populated).
  + Added Russian GRC translation.
  + Updated MAX_OP_RETURN_RELAY to 80 (from 40) for Derp.
* Sat Mar 26 2016 marix@marix.org
- Update to version 3.5.6.0/317
  + Leisure Upgrade
  + Ensure syncing from 0 works properly
  + Ensure client does not stall out after syncing a few K of
    inventory
  + Ensure RPC lag does not occur
* Sun Mar 20 2016 marix@marix.org
- Update to version 3.5.5.9/317
  + Leisure Upgrade
  + Populate Neural magnitude value that is currently 0
  + Handle orphans better to allow new users to sync easier
  + Add OP Return codes when they are enabled
  + Added new key for high DPI monitor support. If text is cut of,
    add this to your config: fontsize=5
  + Added new RPC command to generate burn addresses:
    execute newburnaddress YourVanityString
- Removed patch to fix UPNP support as it was integrated upstream
- Removed patch to hide the upgrade menu, as it was integrated
  upstream
* Sun Feb 21 2016 marix@marix.org
- Update to version 3.5.5.8/317
  + Leisure Upgrade
  + Added a new RPC command to allow data to be stored in burn
    transactions, and modified the RPC to report on the data (or
    custom beacons) in listreceivedbyaddress:
* Sun Jan 31 2016 marix@marix.org
- Update to version 3.5.5.7/317
  + Leisure Upgrade
  + Fixed Rain to handle international currency formatting
  + Added REST support for DAO queries
  + Added DAO to DPC
  + Limit getblocks to 1000 (help enforce hacking attempts)
  + Mitigate Inventory attacks (ensures RPC commands respond
    quickly)
  + Added DAO metric symbol keyname (Will allow querying a DAO
    metric) - Documentation will be available in the whitepaper
  + Restore patch to enable UPNP support as it was _again_ broken
  upstream
* Sat Jan 23 2016 marix@marix.org
- Update to version 3.5.5.5/317
  + Leisure Upgrade
  + Modified Rain RPC to handle global currency formatting
  + Made it possible for users to sync from 0
- Remove patch to enable UPNP support as it was merged upstream
- Remove patch to hide the advanced menu as it was merged upstream
* Sat Jan  9 2016 marix@marix.org
- Update to version 3.5.5.4/317
  + Leisure Upgrade
  + Added 'execute rain' RPC command
* Tue Dec 22 2015 marix@marix.org
- Update to version 3.5.5.3/317
  + Leisure Upgrade
  + Added Binary superblocks
  + We now honor the "datadir" key for the NeuralNetwork
  + Fixed delimiter in DailyNeuralMagnitudeReport.
* Thu Dec 17 2015 marix@marix.org
- Update to version 3.5.5.2/316
  + Leisure Upgrade
  + Add disableneuralnetwork=true if you would like to save the
    hard disk space the neural network consumes.
* Wed Dec 16 2015 marix@marix.org
- Update to version 3.5.5.1/316
  + Leisure Upgrade
  + Require 4 confirms on unconfirmed funds before re-sending GRC
    out through a new transaction
* Tue Dec  8 2015 marix@marix.org
- Update to version 3.5.4.9/316
  + Leisure Upgrade
  + Removed split-stake feature to prevent smaller interest rewards
    and bloated wallets over time.
    Note: After upgrading, please send all your coins back to
    yourself. Then optionally, verify the list is consolidated down
    to only a few entries in coin-control for maximum interest
    staking ability.
* Sun Dec  6 2015 marix@marix.org
- Update to version 3.5.4.8/315
  + Leisure Upgrade
  + Eclipse attack mitigation
  + Neural network will help maintain node trust levels
  + Added network interest payments and %% to list network
  + Added network interest payments and %% to list rsa
  + Removed invalid project error from initial sync
  + Fix neural network bug calculating Bitcoin Utopia RAC
  + Added Last Payment time to overview page
  + Added mandatory URL to 'addpoll'
  + Added key: walletbackupinterval=
  + Modifed Newbie First Block Rule: Requires Magnitude > 0, cpid
    to be in superblock, with a lifetime cpid paid = 0 - Boost is
    now 100,000 for the first block.
- Updated patch to hide the advanced menu
* Thu Dec  3 2015 marix@marix.org
- Update to version 3.5.4.4/314
  + Leisure Upgrade
  + Cosmetic fixes
  + Improvements to the French translation
  + Fixed 'ghost image' in Configuration page
  + Added optional key (stakeall=true) to attempt to stake all the
    coins in the wallet at once
  + Added newbie boost of 25000 weight for blocks 1-5
  + Ensure newbies are immune from mintlimiter rule
  + Added RSA weight to list rsa
  + Added PoolMining value to list rsa and list cpids
  + Set poolmining=true if you use the PiGrid pool
* Sun Nov 29 2015 marix@marix.org
- Update to version 3.5.4.2/314
  + Leisure Upgrade
  + Harden orphan processing
* Thu Nov 26 2015 marix@marix.org
- Update to version 3.5.4.1/309
  + Leisure Upgrade
  + Changed default Max outbound connections to 8 (conserve
    external nodes resources)
  + External nodes disconnect remote nodes hanging on longer than
    2 hours if current connections > 50
  + Nodes disconnect and ban unauthorized nodes for 24 hours (set
    autoban=false to disable)
  + Added remote IP to execute peek (to see if a hang is related to
    a certain IP)
  + Added efficiency to neural network, re-enabled witnesses field,
    1st phase of node to node intelligence
  + Ban nodes repeatedly connecting to external nodes and
    misbehaving for 24 hours
  + Fixed 'execute neuralreport'
* Sun Nov 22 2015 marix@marix.org
- Update to version 3.5.3.7/308
  + Leisure Upgrade
  + Fixed slow shutdown issue
* Fri Nov 20 2015 marix@marix.org
- Update to version 3.5.3.7/307
  + Leisure Upgrade
  + Improved logging and crash protection
* Sun Nov 15 2015 marix@marix.org
- Update to version 3.5.3.4b/306
  + Leisure Upgrade
  + Pull projects and URLs from the dynamic whitelist for NN
    syncing
  + Ensure NN directory exists
  + Fixed NN sync expiration bug
  + If you are an investor and you end up with a CPID, set
    'investor=true' in the config file.
* Fri Nov 13 2015 marix@marix.org
- Update to version 3.5.3.2/306
  + Leisure Upgrade
  + Fixed CPID/Investor detection issue
  + Upgraded Neural Network to pull RAC from the project sites.
    Note that the first time you sync, the system will sync slowly
    while it pulls the project and team data. Successive syncs in
    mid-day will be fast. The NN will attempt to do a full refresh
    once every 24 hrs in the background OR when the superblock is
    exactly older than 86400 as a team.
* Thu Nov 12 2015 marix@marix.org
- Update to version 3.5.2.9/306
  + Leisure Upgrade
  + Added BIP66 code to ensure stake signatures are consistent
    across platforms and refuse malformed sigs
  + Removed potential lag due to contract buffer
  + Moved payments summary to last row of overview page
  + Removed suppresspings.
* Mon Nov  9 2015 marix@marix.org
- Update to version 3.5.2.7/305
  + Leisure Upgrade
  + Added new Europe seednodes
  + Added 'execute peek'.  This will return the last 50k of
    internal messages processed by the message handler.  Unix
    timestamp + Message Name + Byte Length + Message number.
  + More speed improvements to the neural network
  + If exportmagnitude=true then export reports/MassExport.dat.
  + If superblock is pending, do not stake a new superblock.
  + Removed errors + IsMyCPID valid rows in list cpids to reduce
    confusion.
  + Ensure NeuralNetwork directory exists before syncing.
* Mon Nov  2 2015 marix@marix.org
- Update to version 3.5.2.3/304
  + Leisure Upgrade
  + Upgraded Neural Network performance - Added background queue,
    fixed witness calculation
  + Removed extra logging in the NN
  + Fixed NN bug in Europe where some syncing was being skipped
* Sun Nov  1 2015 marix@marix.org
- Update to version 3.5.2.2/304
  + Leisure Upgrade
  + Added investors_cannot_send_beacons to advertise beacon
  + Fixed incorrect Offline message in the overview page
  + Labeled "Foundation Poll" vs "Poll" in overview
  + Added logging to GRCRestarter for -11 error reported in Spain
  + Linux Menus:  Moved startup process to a background thread:
    Note, it may take a couple of minutes for the core to populate
    after booting in this new version.
* Tue Oct 27 2015 marix@marix.org
- Update to version 3.5.2.1/304
  + Leisure Upgrade
  + Fixed inefficiency in neural network
  + Increased Max connections
* Thu Oct 22 2015 marix@marix.org
- Update to version 3.5.1.9/304
  + Mandatory Upgrade
  + Fixed large inefficiency in Neural Network
  + Fixed crash popup sourced from neural network
* Thu Oct 22 2015 marix@marix.org
- Update to version 3.5.1.8/304
  + Mandatory Upgrade
  + Fixed getinfo/explainmagnitude/Literal error
  + Added witnesses field to Neural Network (When a supermajority
    of the NN participants agree on one CPIDs individual project
    RAC on a given day, the nodes will share the information during
    he quorum for the duration of the day) resulting in
    higher efficiency and less re-querying project sites for that
    distinct entry.
  + Grid is no longer locked during syncing.
* Wed Oct 21 2015 marix@marix.org
- Update to version 3.5.1.7/304
  + Mandatory Upgrade
  + Plugged vulnerability discovered by bitcoin - please upgrade to
    this new version asap
  + Added checkpoint
  + Research Age starts at block 364500
  + Mandatory (auto disconnect of other nodes) automatically starts
    at 364500
  + Added business logic to verify superblocks to enforce quality
    of magnitude averages and project averages
  + Retreive explainmagnitude from a synced node otherwise retry
    (with daily limit of 10 retries)
  + Superblock Spacing: 86400
  + Expanded block index starts at 364500 (stores votes/superblock
    indicators more efficiently)
  + Added logging to Neural Network sync process
* Sun Oct 18 2015 marix@marix.org
- Update to version 3.5.1.5/304
  + Leisure Upgrade
  + Disabled windows error mode switch in linux
  + Added avg superblock magnitude to `list superblocks`
  + Added 90 min avg magnitude rule to Prod with backwards
    compatibility (10 for testnet)
  + Set users config file if they cancel the new user wizard, set
    user as investor, and force four addnodes in, and initialize
    mapargs and addnodes after newuser wizard ends.
  + Moved error handler for Tally Network Averages to background
    thread and added Sleep between stop/restart of back thread
    (to prevent repetetive logging)
  + Fixed contract creation problem in the neural network creating
    short contracts
  + Made the wallet try for new superblocks perpetually until it
    finds one that meets expectations.
  + Added 'list superblocks [optional_cpid]' report
  + Improved Tally Network Averages for RA
  + Improved Reorganize to be much more intelligent
  + Made NN more efficient so as to alleviate stress on Project
    Sites
  + Added contract & superblock index fields to Prod starting at
    block 364500 for faster boot time (this is approx. when
    Research Age is released).
  + Added static contracts & superblocks hashes to Prod for
    blocks 1-300000 for faster boot time (70%% of the increase
    occurs now, 30%% more on Nov 1 2015)
  + Require client to be in sync to stake a superblock
  + Require neural network to be synced within 12 hours to create
    a contract, and be complete.
  + Added switch for 24 hour superblocks (currently 12 in prod and
    24 in testnet)
  + Increased Research Age Tally Averages to once an hour to
    increase network stability
  + Made Gridcoin Magnitude Unit snap to grid in .025 increments
    for increased network stability
  + Added local nodes neural hash to getmininginfo
  + Added IsContract and IsSuperBlock to block index (new fields
    start populating @ block 20000)
  + In the mean time, the wallet will scan the chain to backfill
    the values, and you should see a temporary load time speed
    improvement of approx 30%% up to block 20000
    After block 20,000 the speead improvement should be
    substantial. In prod, I tentatively set this for block 350,000,
    but most likely this will be reset to the go-live block as we
    near EOM and finalize more tests.
  + Made contracts/votes use the new index fields - this will allow
    our smart contracts and votes to work forever into the future
    (in contrast to truncating old messages after they are 6 months
    old)
  + Added remove orphan tx logic
  + Added a newer version of reorganize that will recover if the
    wallet fails to reorganize (to disable this add the key
    modernreorg=false)
* Thu Sep 10 2015 marix@marix.org
- Update to version 3.5.0.0/302
  + Mandatory Upgrade
  + Made the system DOS old clients until they upgrade
  + (Advanced users only): Added list memorypool
  * Shows any tx in the raw memory pool rejected by the
    stakeminer and the reason code
  * Shows any tx included in the memory pool accepted by the
    stakeminer
  + Fixed ResearchAge Coinstake Pays too much error
  + Changed linux autounlock hard disk volume HWID command
- Updated patch to hide the advanced menu
* Sun Aug 30 2015 marix@marix.org
- Update to version 3.4.9.0/299
  + Leisure Upgrade
  + Added execute shavechain. This should allow us to recover
    during failed re-orgs in the future. (All done automatically).
  + Added higher security to the autounlock feature. Please update
    your autounlock passwords with 'encrypt pass' and update the
    config file
  + Fixed checkblock and researcher pays too much errors
  + Added feature to the NN to track all average magnitudes and
    share the info with other nodes (may enhance security in RA in
    the future for blocks over 500grc)
  + Fixed update confirmation of coins error from Poochie
  + Fix autounlock
  + Fixed NN backspace error
  + Fixed Derp error
  + Refactored Lifetime fields for RA
  + Fixed Satoshi log error
  + Fixed European GRC conversion error and removed Quotes from NN
    list (will still be in getmininginfo)
  + Fixed GRCQuote and BTCQuote in getmininginfo
  + Added Prod TallyNetworkAvgs code to prevent segfault
  + Made wallet unlock for staking only when unlocked with the
    'autounlock' feature
  + Moved superblock and key fields to block index
  + Refactored TallyNetworkAverages to use blockindex instead of
    disk
  + Removed old unused functions from Gridcoin Classic
  + Made syncing from zero also adhere to the same tallying rules
  + Allow RA to load superblocks when restarting from 0; fixed
    Segfault
  + Added voting message notifying user when voting in a Both
    Share Type poll stake age Or your CPID age must be older than
    the poll duration.
- If anyone is having trouble syncing in prod, from the command
  line do a 'grcrestarter upgrade', then
  'grcrestarter downloadblocks' (new snapshot sent up)
* Thu Aug 20 2015 marix@marix.org
- Update to version 3.4.8.1/295
  + Leisure Upgrade
  + Added additional code for recalculating lifetime payments, last
    block paid during any reorg, disconnect or connect
  + Added more RA pre-prod security
  + Researchers reward pays too much should be fixed, along with
    PPD messages in the log
  + Added key called "sponsor". The default is false.
    Sponsoring CPIDs will not occur unless you set sponsor=true. In
    addition, higher security has been added to prevent spamming.
  + Added higher security to prevent Explain Magnitude spamming.
* Tue Aug 18 2015 marix@marix.org
- Update to version 3.4.8.0/295
  + Leisure Upgrade
  + Only allow sponsorship of one distinct CPID per day per address
    (will add a key to shut off feature ASAP)
  + Allow a newbie Verified CPID with Mag > 1 to stake with 0 grc
    balance (completely untested, please test) - Only works with
    Research Age
  + Added GRC Quotes and BTC quotes to the neural network
  + Added GRC Quote to getmininginfo
  + Fixed rounding problem for POR Research Age Reward
* Sun Aug 16 2015 marix@marix.org
- Update to version 3.4.7.8/294
  + Leisure Upgrade
  + Added beacon sponsorship system: execute advertisebeacon neural
    Will send a beacon through the neural network, another host
    will sponsor the CPID and send the beacon (allowing users with
    0 grc to enter the NN)
  + Added 'list staking' staking report.  This will explain in
    detail what coins are eligibile for staking by the stakeminer.
    The first phase of the report shows coins with enough age to
    stake. The second phase of the report shows coins the
    stakeminer will pick up for staking.  It also shows the
    stakeable balance.
  + Finally found the root cause of some nodes not staking
    regularly (probing coin age constantly).  The problem was some
    coin wallet tx totaling zero were taking precedence in stake
    miner - ie hogging up the position of Highest priority to
    stake, because they were the oldest, but worth the least.
    Stakeminer cant stake unless it finds more than 0 coins in a
    set.
  + Fixed crash (segfault) affecting either syncing from zero, or
    certain reorgs in the coin.
  + Added all CPID interest to lifetime interest field (list rsa)
    Lifetime Interest (not just POR block interest).
  + Fixed POR indicator in tx list (showing certain POR as
    Interest only)
  + Added MiningErrors8 to getmininginfo and to overview.  If you
    are probing coin age for more than 10 minutes, this field will
    show what is going on in the stakeminer.
    If it says, Kernel Found 0: that means coin age is not mature
    enough. After approx 5 mins, Kernel Found should increase to a
    portion of the coins in the Stake bucket.  Once that happens
    the node will stake as soon as it passes the mintlimiter
    threshhold for the diff level.
  + Added Lifetime Average Magnitude to list rsa.  This will be
    valuable to see the long term payments per day per magnitude in
    the future.
  + Fixed issue where client was constantly probing coin age.
  + Added LastPORBlockHash to showblock. (Note: this will only
    populate going forward, after 8-13-2015).
  + Fixed historical calculation problem in list rsa Lifetime
    Research payments field.
  + Removed unecessary logging with fDebug=true on.
  + Added Earliest Payment field to list rsa (Note: The earliest
    possible payment date is the day we switched to the new block
    index - around July 4th 2015, so payments before that date
    are not counted in Lifetime payments nor earliest age).
  + Added Tx Count to list rsa to make it easier to reconcile list
    lifetime <yourcpid>
* Wed Aug 12 2015 marix@marix.org
- Update to version 3.4.7.5/293
  + Leisure Upgrade
  + Research Age: Handle disconnects gracefully for all types of
    reconnects
  + Added lifetime paid per day
  + Added 'list lifetime cpid' report to show block numbers and
    amounts to reconcile lifetime payments
  + Accrual Age: Handle disconnected blocks more gracefully and
    rescan CPIDs last solved
  + During Reorgs: If we reorg 3 times, move the best block back
    100 blocks for every reorg attempt; reset counter after a
    successful reorg
* Mon Aug 10 2015 marix@marix.org
- Update to version 3.4.7.3/293
  + Leisure Upgrade
  + Fixed issue where client may lose vote data during a full sync
    from zero; and prevent GRCMagnitudeUnit from not being
    populated
* Sun Aug  9 2015 marix@marix.org
- Update to version 3.4.7.2/293
  + Leisure Upgrade
  + Mandatory Upgrade for TestNet
  + Neural Network: Discover majority average per cpid and discard
    erroneous values
  + Added Question to execute votedetails
  - Added feature to neural network to allow nodes to track
    historical magnitude per cpid and share it among the network,
    and provide lookups for research age history
  + Added Average magnitude to neural network (possibly replaces
    magnitude for research age calculation - includes 120 day
    lookback and network consensus and square of distance lookup)
  + Added phase I of intelligence to the neural network for
    probabilities; and real time communication among each node
    (new memory layer allows the nodes to agree on memories)
  + Made minimum addpoll balance = 100k GRC.
  + Made Best Answer null until Participants equal at least 3.
  + Made minimum poll duration 7 days.
  + Made StakeMiner verify CPID and hashboinc before submitted a
    block that then turns to orphans
* Wed Aug  5 2015 marix@marix.org
- Update to version 3.4.6.3/291
  + Leisure Upgrade
  + Added key fullbore=true (false by default) removes sleep
    statements in the miner
  + Fixed slow syncing from zero
  + Made the UI update every 100 blocks during syncing
  + Optimized chatter when not voting
* Tue Aug  4 2015 marix@marix.org
- Update to version 3.4.6.1/291
  + Leisure Upgrade
  + Added auto-column width to voting list
  + Added BL rule for superblocks enforcing maximum average mag to
    prevent corrupt superblocks
- Updated patch to hide the advanced menu
* Sat Aug  1 2015 marix@marix.org
- Update to version 3.4.6.0/291
  + Leisure Upgrade
  + Added network traffic graph to RPC Console
  + Fixed tooltip background colors & split message into rows
  + BLK_1.1.2_Security1: Limited number of orphan blocks stored in
    memory
  + BLK_1.1.2_Security3: Fixed potential network-wide dos by
    malleability of block signatures
  + BLK_1.1.2_GUI1: Made the toolbar unhidable
  + BLK_1.1.2_GUI2: Fixed shortcuts ALT+2 and ALT+3
  + BLK_1.1.2_RPC1: Fixed output of getstakinginfo in a rare case
  + BLK_1.1.2_RPC2: Added addnode/getaddednodeinfo commands
  + BLK_1.1.2_RPC3: Added rescan argument to importprivkey
  + BLK_1.1.2_RPC4: Added addrlocal field to getpeerinfo
  + BLK_1.1.2_Protocol1: Permitted one data txout per non-data txout
  + BLK_1.1.2_Protocol2: Add a notfound message to getdata that is
    sent if any transactions that aren't in the relayable set are
    requested.
  + BLK_1.1.2_Protocol3: Added rejection of non-null CHECKMULTISIG
    dummy values
  + BLK_1.1.2_Protocol4: Increased standard scriptSig length
    (Removes the limits on number of pubkeys for P2SH CHECKMULTISIG
    outputs)
  + BLK_1.1.2_Protocol5: Removed "checkorder" and "reply" messages
  + BLK_1.1.2_other1: Updated default -rpcsslciphers to include
    TLSv1.2
  + BLK_1.1.1_GUI3: Getpeerinfo shows ping to connected nodes
  + BLK_1.1.1_GUI4: Listunspent and signrawtransaction made
    p2sh-aware
  + BLK_1.1.1_GUI5: Fixed staking icon sometimes shows 0 weight
  + At block 282410, we had an interest payment over by .01grc
    causing a fork.  I had previously fixed this issue, but it had
    to be changed to include fees.  Fixed.
  + Updated snapshot
  + Verified you can now sync forward to the best block
  + Incremented grandfather (after root cause was fixed)
  + Added -zapwallettxes (please test)
  + RSA weight bug for newbies fixed
  + Added bitcoins 'listtransactions' so we can see all
    transactions.
  + Refactor showorphans (key)
  + Added RSA weight and CPID to getmininginfo
  + Ensure DPOR Magnitude is staked in newbie blocks
  + Made money supply handle NULL blocks and recover money supply;
    coin will auto patch money supply value if it is already reset
    or < GenesisSupply
  + Added list magnitude CPID (So you can pull up the magnitude
    report/RSA for any CPID)
  + Made the earliest stake time / cpid time use the index for
    voting to speed up the voting process (Note: This will take 10
    more days to backfill in the index, so it will not may any
    immediate difference today).
  + Update NN Quorum data on NN overview page every 5 blocks
  + Removed slight inefficiency in NN and added the signature to
    list explainmagnitude (this will take a while to propogate)
  + Fixed inability to detect earliest stake age for Voting
  + Added Last superblock block number, last superblock timestamp,
    and current popular hash to NN overview; It updates every 5
    blocks (added execute updatequorumdata if you want to test it)
  + Added Multiple Choice Voting for windows and linux (execute
    vote command supports semicolon delimited answers)
  + Enhanced Voting Form to handle polls with up to 20 answers
  + Multiple choice voting applies total vote weight across answers
    chosen evenly
  + Added beacon/vote cost warning to overview
  + Fixed NN chatter during client startup
  + Enhanced list explainmagnitude (requires a majority to update
    before you can see it)
  + Added 'execute versionreport'
  + Added crash protection in TallyNetworkAverages and checks for
    Genesis Block
  + Added 'tally' field to getinfo and to overview: shows the
    minimum block height the coin has memorized while creating
    everyones RSA account
  + Added QuorumHashingAlgorithm to replace md5 for neural network
    communication.  This allows NN nodes to agree on everyones
    magnitude more quickly.
    (The previous NN hash is left in for legacy support until the
    next mandatory, so superblocks can now stake using the old
    system or the new system).
    We will have to have a lot of nodes to upgrade to see the
    neural report content decrease to a much higher majority.
    We will need a majority of windows nodes to upgrade for the
    new system to work. Next mandatory, we can remove legacy hash.
  + Added Pending superblock to 'execute neuralreport'.  This shows
    the block number of an accepted pending superblock that has not
    yet been loaded by the coin.  The coin loads the superblock as
    a team 15 blocks after the block is staked successfully.
  + Added contract beacon count and contract hash to contract
    details for debugging - tested QHA successfully
  + Only add neural hashes to blocks if superblock is old and NN
    is live and working - to clean up the neural report
  + Removed more unecessary logging and fixed problem where large
    blocks were not being forwarded to other nodes and becoming
    orphans
  + Made list explainmagnitude connect to the neural network and
    pull down the actual mag report for the user for consistency
  + Fixed problem where certain CPIDs could not vote due to a bad
    CPID age (you can run execute staketime to verify age if you
    have a problem)
  + Added 'execute listallpolls' to show non-expired + expired
    polls
  + Added 'execute listallpolldetails' to show details for polls
    including expired polls
  + Added 'execute listpollresults pollname true' to show expired
    poll results (use execute listpollresults pollname for
    non-expired)
  + Removed unecessary logging
* Fri Jul 24 2015 marix@marix.org
- Update to version 3.4.4.8/288
  + Mandatory Upgrade
  + Note this version requires a Resync from Zero!
    Execute `gridcoinupgrader downloadblocks` before starting the
    gridcoinresearch after the update.
  + Retally owed amounts during a chain reorg Or before rejecting
    the block due to 'Researcher Reward Pays Too Much' error
  + Made blockindex fields non deterministic - to fix money supply
  + Removed more unecessary logging
  + Incremented grandfather
* Thu Jul 23 2015 marix@marix.org
- Update to version 3.4.4.7/288
  + Mandatory Upgrade
  + Fixes crash (switched to the blockindex)
  + Hardened TallyNetworkAvgs and AddNetworkMag
  + Moved Superblock computations out of TallyNetworkAvgs for more
    resilience
  + Made NN list sort numerically instead of by string
* Wed Jul 22 2015 marix@marix.org
- Update to version 3.4.4.3/287
  + Leisure Upgrade
  + Added detailed crash log pointers (set debug3=true in config to
    enable)
  + Added two charts to neural network (This will take 30 days to
    populate)
  + Added Last Synced, CPID and Quorum Hash to neural network
    overview
  + Added crash protection to Advertise Beacon and Miner
  + Added 1 grc to ConnectBlock for Researchers Reward for CPID %%s
    pays too much
* Mon Jul 20 2015 marix@marix.org
- Update to version 3.4.4.2/287
  + Mandatory Upgrade
  + When superblock is old, we compute neural hashes more often;
    when superblock is current we slow down computations
  + Added extra check in list cpids
  + Made tallying more efficient
  + Added checkpoint and incremented grandfather block
* Sat Jul 18 2015 marix@marix.org
- Update to version 3.4.4.1/286
  + Mandatory Upgrade
  + We now enforce participant count in superblocks - count must
    match beacon list count
  + This version rolls our superblock back to the last valid
    superblock automatically
  + Added more crash protection in 3 places.
  + Fixed problem where list cpids was not mapping to official
    name. Fixed inadvertent load of invalid non mineable cpid.
    Fixed creditcheck mechanism for list cpids.
- Updated patch to hide the advanced menu
* Fri Jul 17 2015 marix@marix.org
- Update to version 3.4.3.8/285
  + Mandatory Upgrade
  + Added RAC Check > 10 in GetNextProject for Valid CPIDs, but
    removed RAC check in checkblock (since we reward by total
    magnitude)
  + Fixed Orphaned block Message Crash issue
  + Neural network overview : 500%% faster
  + Fixed bug where empty email address will not allow user to
    become investor
  + Fixed region/culture issue in NN where regions with commas
    corrupt the block
  + Added Total RAC to superblock
  + Fixed explainmagnitude: But, this will not go into effect until
    the next superblock
  + Re-optimized TallyNetworkAverages
* Thu Jul 16 2015 marix@marix.org
- Update to version 3.4.3.5/283
  + Leisure Upgrade
  + Fixed infinity error in neural network drill in
  + Moved to newest magnitude formula based on Total Contributions
  + Removed MinRAC in neural network
  + Magnitude Formula is now: Magnitude = (TotalRACContributions  /
    ProjectRAC) / (WhitelistedProjectsCount)) *
    NeuralNetworkMultiplier (Neural Network Multiplier is a static
    115000 to keep Mags on par with prior values).  (Removed
    'CountOfTotalProjects' from NN formulas).
  + Adjusted execute explainmagnitude2 to match NN formula.
    Note: list explainmagnitude is not updated in the core yet -
    will be done asap. Use the NN or explainmagnitude2 in the
    interim.
  + Added totals to neural network drill in page (and Total RAC)
    and added Total RAC to NN overview
  + Enabled Quorum communication
  + Added auto purge for debug2.log
  + Let the Games Begin!
* Wed Jul 15 2015 marix@marix.org
- Update to version 3.4.3.4/282
  + Leisure Upgrade
  + Refactored TallyNetworkAverages
* Tue Jul 14 2015 marix@marix.org
- Update to version 3.4.3.3/282
  + Leisure Upgrade
  + Fixed segfault on load
  + Added backbone for intelligent neural network communication
* Sun Jul 12 2015 marix@marix.org
- Update to version 3.4.3.2/281
  + Mandatory Upgrade
  + Exchange Release Version
  + Made loading the superblock graceful so we will not fork
  + Cleaned up list cpids, list network - removed some fields that
    are now driven by the neural network
  + Added GRC Magnitude Unit to list network for support of future
    accruals
  + Added side-by-side accrual staking.  After you stake a research
    block, you may look at the block and see the ResearchAge,
    MagnitudeUnit and FutureResearchSubsidy.
    Please take a look at those to verify this system will work for
    us in the future.
  + Added Accrual fields to showblock
* Sun Jul 12 2015 marix@marix.org
- Update to version 3.4.3.1/280
  + Mandatory Upgrade
  + Fixed Invalid CPID error
  + Added progress bar to neural network overview, and fixed zero
    problem for good
* Sat Jul 11 2015 marix@marix.org
- Update to version 3.4.3.0/278
  + Mandatory Upgrade
  + Fixed Moo! and similar whitelist problems
  + Added Magnitude, ResearchSubsidy, InterestSubsidy and CPID to
    our block index for faster future performance
  + Fixed Neural zero magnitude issue
  + Added execute explainmagnitude2 to RPC. This is our first linux
    neural network command!
  + Block structure changes at 271625 - please upgrade by then
    otherwise you may have to downloadblocks
* Sat Jul 11 2015 marix@marix.org
- Update to version 3.4.2.9/278
  + Leisure Upgrade
  + Fixed bug where user is stuck in investor mode
  + Fixed bug where neural network is not removing underscores from
    Whitlisted projects (for example bitcoin_utopia)
    therefore mags were zero in neural network for BU
  + Neural Network:
  * Made Refresh button work
  * Made search work by start of string or instring
  * You can now sort by any column
  * Made Refresh professional
  * Added Whitelisted Projects Count and Total Projects Count to
    Neural overview
  * Neural CPID Drill in Page:
  - Added Red background to Blacklisted Projects
  - Added Yellow background to projects not meeting minimum
    RAC
  - Added extra columns to show cumulative effect of each
    project and to replace explainmagnitude
  * Added Grid View for Projects showing all Gridcoin projects
    and all whitelisted projects to neural overview
  + Added buffer protection in 50 places - SeP or headless users,
    please test for double free corruption, Also please add
    'debug3=true' to your config - this should show where the
    problem is if it occurs again (you should see numbers in this
    case)
  + Note: Mag calculation was off due to the blacklist
    calculation, it is correct now and should fix itself during the
    next superblock.
  + Set MiningCPID back to INVESTOR when Gridcoin calculates an
    invalid CPID
  + Added CPID to overview
* Thu Jul  9 2015 marix@marix.org
- Update to version 3.4.2.7/278
  + Mandatory Upgrade
  + More efficient superblocks and quorum (also, fixed race
    condition preventing neural from rehashing during a sync in
    progress)
  + We now send the whitelist to the neural network
  + The neural network sends Gridcoin the network averages
    (starting after the next future superblock)
  + Fixed bug where user is stuck in investor mode
  + Prevent empty mag contracts
* Tue Jul  7 2015 marix@marix.org
- Update to version 3.4.2.6/278
  + Mandatory Upgrade
  + Coin will not load a superblock with avg mag < 10
  + Coin skips by corrupted beacons
  + added execute superblockaverage
    (Last valid superblock is re-loaded now)
* Tue Jul  7 2015 marix@marix.org
- Update to version 3.4.2.5/277
  + Mandatory Upgrade
  + Rollback to block 267500
  + Disabled RemotePayments feature
  + Made neural network stake two superblocks per day
* Mon Jul  6 2015 marix@marix.org
- Update to version 3.4.2.4/275
  + Mandatory Upgrade
  + Security Update
  + Fixed magnitude report to use whole days
  + Fixed problem in list cpids that Typhoon/DC7D mentioned with
    minimum RAC causing an invalid CPID
  + Fixed resetcpids to actually reset
  + Removed invalid team errors from core
  + Clear POS errors when stake mining successfully starts
* Sun Jul  5 2015 marix@marix.org
- Update to version 3.4.2.2/271
  + Leisure Upgrade
  + Added Diagnostics
* Sun Jul  5 2015 marix@marix.org
- Update to version 3.4.2.2/271
  + Mandatory Upgrade
  + Synchronized start and stop blocks for global magnitude and
    payments structure
  + DPOR pays highest owed first
  + OutstandingOwed and GRCAddress in Magnitude report
  + Bug fix for DPOR system
  + Neural network assesses researcher magnitudes
  + Daily Magnitude Contract drives RSA and each users DPOR
    magnitude value
  + Superblock is verified by the majority of the neural network
    otherwise rejected
  + DPOR/Remote Payments provides unlimited scalability (Remote
    payments are verified during each CheckBlock otherwise
    rejected)
  + Dynamic minimum RAC
  + Dynamic boinc whitelist
  + Simplified RSA
  + 100%% hard blockchain checks in block acceptor based on daily
    magnitude contract
  + Removed Netsoft and all dynamic calls for RAC
  + Magnitude < 1 > .25 bugfixes
  + New rules start @ block 267504
* Fri Jul  3 2015 marix@marix.org
- Update to version 3.4.1.5/272
  + Mandatory Upgrade
  + New rules start @ block 267449
  + Neural network assesses researcher magnitudes
  + Daily Magnitude Contract drives RSA and each users DPOR
    magnitude value
  + Superblock is verified by the majority of the neural network
    otherwise rejected
  + DPOR/Remote Payments provides unlimited scalability (Remote
    payments are verified during each CheckBlock otherwise
    rejected)
  + Dynamic minimum RAC
  + Dynamic boinc whitelist
  + Simplified RSA
  + 100%% hard blockchain checks in block acceptor based on daily
    magnitude contract
  + Removed Netsoft and all dynamic calls for RAC
  + Modified caption on remote payment in TX List to be :
    Minted - DPOR, Mined - DPOR (Mined is remote, Minted is local)
  + Shortened Answer column in Vote List so we can see all the
    columns
  + Added Last Active Poll to Overview Page - Bottom - When this
    value changes, you know a new poll has started (We will add a
    real Alerts Page eventually with memory of read items)
  + Made the minimum RAC 10 in list cpids, so users can have valid
    CPIDs on lower RAC projects (the Neural Network now creates
    magnitude contracts based on a dynamic MinRac)
  + Made DPOR mag below 25 round to nearest .25 and ensured a Mag
    of 1 does not get rounded to zero
  + Added protection in advertise beacon
  + Made testnet minimum owed 40000 GRC for every CPID - so we can
    test remote payments received until the barrier is hit
  + Made Remote payment verification in block acceptor actually
    reject the block
  + Added Remote payment verification to stake miner - also made
    stake miner restart with fresh data when recipients change
  + Incremented grandfather block in testnet to 26500 - IE new
    rules start at block 26500 in testnet
  + Fixed the Total RAC column in the Neural Network to be Total
    RAC
  + Fixed interest calculations for DPOR
  + Added interest amount and Block # to list detailmagnitudecsv
  + Verified RSA interest value in testnet
* Sat Jun 27 2015 marix@marix.org
- Update to version 3.4.0.6/264
  + Leisure Upgrade
  + Only sync DPOR as a team once every 30 blocks, and only right
    before superblock expires
  + Made neural granularity 5
  + Added two new vote types: ShareType 4 = CPIDCount,
    ShareType 5 = Participant Count
  + Added two new polls to exercise types 4 & 5
  + Added double vote protection - CPID age must be older than vote
    duration for magnitude votes to count (Type 1 & 3), Stake Age
    must be older than vote duration for Balance votes to count
    (type 2 & 3)
  + Made the blue remote payment caption "Mined - DPOR"
  + Added 10000 GRC to what is OWED to each recipient in TestNet
    only
  + Added a new payment tracking vector for DPOR.  List RSA will
    show the new value.  This is now used for the block acceptor in
    testnet.
  + Made the block acceptor work in TestNet.
* Sun Jun 21 2015 marix@marix.org
- Update to version 3.4.0.6/261
  + Leisure Upgrade
  + Added decentralized voting (See guide:
    http://finance.gridcoin.us/images/gridcoin%%20decentralized%%20voting%%20system.pdf)
  + Added 'execute votedetails pollname' to rpc.  This report shows
    the Shares voted per address and cpid, the answer to the
    question, and the sharetype for a specific poll allowing people
    to audit individual vote shares (find themselves etc).
    It also shows the current MoneySupplyFactor, which is the
    MoneySupply/TotalNetworkMagnitude used for the weight for
    Magnitude for 'Both' (hybrid) type votes.
  + Hybrid votes now reflect the MoneySupplyFactor weight in the
    poll results/etc.
  + Made smart contract tiny amounts show in the txlist
  + Made neural network honor testnet flag (IE neural net is stored
    in Testnet directory)
  + Added Red Testnet Label to the screen.
  + Testers, please upgrade, then execute: 'execute syncdpor2' from
    the command line, then open the neural network screen to verify
    the cpids are present.
  + Added minor version to getpeerinfo so we can see that everyone
    in testnet upgraded
  + Fixed AddMultiSigAddress bug
- Updated patch to hide the advanced menu
* Tue Jun 16 2015 marix@marix.org
- Update to version 3.4.0.6/257
  + Leisure Upgrade
  + Added minor version to "getinfo"
  + Made testnet use DPOR magnitude for RSA amount owed
  + Added RAC XML Report to CPID Drill In screen
* Sun Jun 14 2015 marix@marix.org
- Update to version 3.4.0.5/255
  + Leisure Upgrade
  + Added "execute beaconreport"
  + Added "execute superblockage" (lets us see how old the
    superblock is and what block number it appears on)
  + Added super block length to showblock (only appars if you view
    the block with the superblock)
  + Removed unecessary mandatory upgrade check
  + Added neural network, offchain persisted data system,
    linux->windows communicator, supermajority hashing system,
    neural hash report ("execute neuralreport"), neural gui
  + Added beacon system to allow DPOR nodes to tally active CPIDs,
    and to allow newbies to start without staking
  + Added "execute rac CPID"
  + Lowered fee from .25grc to .05grc for a smart contract
  + Added smart contract expiration date
  + Added "list opencontracts" to run the Open Contracts report.
  + Added DPOR (run side-by-side to legacy system)
- Updated patch to hide the advanced menu
* Mon May 25 2015 marix@marix.org
- Update to version 3.4.0.5
  + Leisure Upgrade
  + Re-Enabled GRC addresses in TX List so we can see who we sent
    GRC to
  + Added Total Network Magnitude and Avg Network Magnitude to
    "list network"
  + Added a MagnitudePaymentUnit.  This is the Max GRC emitted per
    day divided by total network magnitude.
    The coin still pays the same GRC reward amount UNLESS rewards
    exceed the magnitude unit (IE Your Magnitude *
    MagnitudePaymentUnit). In that case, the user receives the
    network magnitude payment unit * magnitude.
    This is a leisure upgrade until fully tested them we can turn
    the feature on in prod.
  + Added magnitude unit to list rsa.
  + Added feature to make it easure for new users to come on board
    (Minimum block spacing of 30 mins for POS users).  We already
    have a minimum of 2 hours for the POR side.
  + Removed Testnet constant fake pay per block (500) to simulate
    real world conditions.
- Updated patch to hide the advanced menu
* Fri Apr 24 2015 marix@marix.org
- Update to version 3.4.0.2
  + Leisure Upgrade
  + Removed zero coin library and various other things
* Thu Apr 23 2015 marix@marix.org
- Update to version 3.4.0.1
  + Leisure Upgrade
  + Removed all extraneous Gridcoin Classic functions from Research
    codebase
  + Removed 90%% of dead code
* Wed Apr 15 2015 marix@marix.org
- Update to version 3.4.0.0
  + Leisure Upgrade
  + Enabled Cryptolottery (TestNet only)
* Sat Mar 14 2015 marix@marix.org
- Update to version 3.3.9.9
  + Leisure Upgrade
  + Added Gridcoin Persisted Data System to the coin (TestNet only)
* Fri Mar 13 2015 marix@marix.org
- Update to version 3.3.9.8
  + Leisure Upgrade
  + Removed one line of repetetive logging
  + Added generic data storage system to block chain
  + Added RPC commands : 'execute addkey', 'execute memorizekeys',
    'execute listdata'
  + Fixed issues with UPNP and QR code generation.
  + Improved look of hover-over tooltips
  + Timestamp for CSV mangitude report (list magnitudecsv)
  + Upgrader fixed to find the headless deamon
  + Improved toolbar icon.
- Removed QR-code patch as it was integrated upstream
- Removed window icon patch as it was integrated upstream
- Removed upgrader patch as it was integrated upstream
* Wed Mar  4 2015 marix@marix.org
- Hide upgrade option in GUI as it's useless on a packaged client
- Hide advanced options in GUI as they don't work on Linux, yet
* Wed Feb 18 2015 marix@marix.org
- Update to version 3.3.9.7
  + Mandatory Upgrade
  + Fixed problem with explainmagnitude related to Universe@Home
    and other re-mapped project names
  + Fixed contact@gridcoin.us e-mail (please don't send emails lol)
  + Enabled testnet (current block 0)
* Sat Feb 14 2015 marix@marix.org
- Update to version 3.3.9.6
  + Leisure Upgrade
  + Fixed underlying problem for Universe@home & Find@home.  Added
    error message when project is not in netsoft.  Removed Invalid
    CPID message when Project is invalid.
  + Added Find@Home->fightmalaria to OfficialName
  + Approve Research payments of 0 when Interest is still due on
    the block (suppress Chain Payment Violation).
* Fri Feb 13 2015 marix@marix.org
- Update to version 3.3.9.5
  + Mandatory Upgrade
  + SelectCoinsForStaking only stakes 1/2 of the available coins if
    you are a researcher;  Investor behavior is unchanged.
  + Added Universe@Home mapping.
* Wed Feb 11 2015 marix@marix.org
- Update to version 3.3.9.4
  + Mandatory Upgrade
  + Plugged hole in payment system where retired project payments
    were not being counted against a cpid.
  + Modified logic for Next Estimated Payment to be accurate.
  + Fixed Universe@Home init.
* Sun Feb  8 2015 marix@marix.org
- Update to version 3.3.9.3
  + Mandatory Upgrade
  + Refreshed Project List for Leiden Classical
  + Transition Block 136635
* Sat Feb  7 2015 marix@marix.org
- Update to version 3.3.9.2
  + Mandatory Upgrade
  + Fix Climate Prediction, Leiden Classic, LHC@Home,
    VirtualLHC@home - Readded Burp, MindModeling@Beta, and
    Radioactive@Home
* Sat Feb  7 2015 marix@marix.org
- Update to version 3.3.9.1
  + Mandatory Upgrade
  + Refreshed Project List
* Sat Feb  7 2015 marix@marix.org
- Update to version 3.3.9.0
  + Mandatory Upgrade
  + Refreshed Project List
  + Transition block: 135255
* Fri Feb  6 2015 marix@marix.org
- Update to version 3.3.8.9
  + Mandatory Upgrade
  + Enabled Bitcoin Utopia. Please let us know if the project
    fails.
  + Fixed execute genboinckey: Note: You will have to regenerate
    the key as the old keys did not contain enough info:
  * execute genboinckey (from the node with the attached
    projects)
  * Add the boinckey to the config to the node without the
    projects.
  * Restart the node.
  + Added POR Boost to first 5 blocks for newbies
  + Renamed RRSA to RSA Weight, and removed the 3 unecessary
    fields.
  + Adjusted the Green POR Block priority to Gold then Green
  - Transition block: 135130
* Thu Feb  5 2015 marix@marix.org
- Fixed missing requirement of headless deamon to upgrader
* Wed Feb  4 2015 marix@marix.org
- Added the upgrader
  + Included a patch to let the upgrader find the headless daemon
* Wed Feb  4 2015 marix@marix.org
- Update to version 3.3.8.8
  + Leisure Upgrade
  + Added green POR mined indicator for POR mined blocks
  + Added the option to download the blocks via HTTP
  + Added client restart via RPC
* Tue Feb  3 2015 marix@marix.org
- Update to version 3.3.8.7
  + Mandatory Upgrade
  + Assess Chain Violations as of T-14 (make stakeminer match RSA
    LTO)
  + Transition Block: 131764
* Mon Feb  2 2015 marix@marix.org
- Update to version 3.3.8.6
  + Mandatory Upgrade
  + Bugfix: Calculation of ChainViolation check now honors CPIDs
    with high mags
  + Transition Block: 130890
* Sun Feb  1 2015 marix@marix.org
- Update to version 3.3.8.5
  + Mandatory Upgrade
  + Bugfix: An error in the calculation of the LastPaymentTime
    caused POR blocks not to be paid
  + Transition Block: 130670
* Sun Feb  1 2015 marix@marix.org
- Update to version 3.3.8.4
  + Mandatory Upgrade
  + Added Green POR mined indicator for POR mined blocks/ Yellow
    means interest blocks  (Old mined POR blocks should now be
    yellow - this affects future blocks only)
  + Modified CPID maximum magnitude range to be 1-2000 (from 80%% of
    MaxBlockSubsidy) - Lederstrumpf algo makes it exponentially
    harder to reach 2000 after 90%% of the mag is reached (starting
    at 1800 mag)
  + Added ability to pay researcher up to 5 blocks per day
  + RSA long term owed is now based on Mag*Multiplier*14 with a
    Maximum POR capped subsidy of MaxBlockSubsidy*14*5 (IE high
    magnitude CPIDs may earn up to 5 blocks per day to be
    compensated properly)
  + Transition Block: 130540
* Mon Jan 26 2015 marix@marix.org
- Update to version 3.3.8.3
  + Mandatory Upgrade
  + This fix should make linux nodes equal to win nodes.
  + Extremely detailed logging in kernelhash (but only when it
    fails) enabled via debug3=true
  + Increased hashes required ps in coinstake calculation to
    attempt to control the diff better.
  + Set transition block to 124895
  + Verified the github version of gridcoin.h has the correct key;
    you should not need the key to sync.
  + Removed CPIDGuid from the kernelstake calculation - it turns
    out, it is not cross platform compatible.  That would explain
    why we have so many differences in consensus (hopefully).
  + This would also explain why people were receiving different
    results syncing from zero!  Should be resolved now.
* Sun Jan 25 2015 marix@marix.org
- Update to version 3.3.8.1
  + Leisure Upgrade
  + Added 4 checkpoints up to last block
  + Grandfathered up to current block
* Sat Jan 24 2015 marix@marix.org
- Update to version 3.3.8.0
  + Leisure Upgrade
  + No longer requre a private key to connect
* Fri Jan 23 2015 marix@marix.org
- Update to version 3.3.7.9
  + Leisure Upgrade
  + Release Candidate 2
  + Fixed network weight value (overview, getmininginfo, stake
    icon) & Est time to earn reward
  + Renamed Mining Errors to MiningInfo
  + Removed PoW messages
* Fri Jan 23 2015 marix@marix.org
- Update to version 3.3.7.8
  + Mandatory Upgrade
  + Release Candidate 1
  + Transition block: 122114
  + Fixed negative interest payment (RTM) - This did not result in
    any inaccurate payments - GUI only
  + Raised grandfather to pass the bad block @ 121220
  + Adjusted PoR difficulty algorithm nBits for less solutions per
    second
* Thu Jan 22 2015 marix@marix.org
- Update to version 3.3.7.7
  + Mandatory Upgrade
  + Transition block: 121219
  + Increased minimum stake amount to 1 (up from .50grc)
  + Removed PoW
  + Adjusted PoR difficulty algorithm to be 100 times harder for
    less solutions per second
* Wed Jan 21 2015 marix@marix.org
- Update to version 3.3.7.5
  + Mandatory Upgrade
  + Transition block: 120830
  + Increased minimum stake size to .50 (up from .25grc) and
    increased PoW slightly
  + Added anti-hack mintlimiter rule with dos
  + Made mintlimiter dynamic (IE handle decreasing subsidy
    schedule)
* Wed Jan 21 2015 marix@marix.org
- Update to version 3.3.7.4
  + Mandatory Upgrade
  + Transition block: 120400
  + Increased minimum stake size to .25 (up from .01 grc)
  + Removed some logging - fine tuned orphan punishment rule not to
    constantly dos other nodes
  + Enabled PoW
* Tue Jan 20 2015 marix@marix.org
- Update to version 3.3.7.3
  + Mandatory Upgrade
  + Fixed orphan problem!
  + Transition block: 120310
* Tue Jan 20 2015 marix@marix.org
- Update to version 3.3.7.2
  + Mandatory Upgrade
  + Added a 10grc minimum mint on POR blocks when diff > 1
  + Added anti-orphan block acceptor rules to CheckBlock
  + Fixed block corruption problem
  + Added rule to vehemently reject non-signed blocks or blocks
    forwarded from unknown versions
  + Removed ability to submit blocks into our network outside of
    the client
  + Transition block: 119810
* Sun Jan 18 2015 marix@marix.org
- Update to version 3.3.7.1
  + Mandatory Upgrade
  + Disabled POW so we can test one thing at a time
  + Shuffled POR2.0 weights around to place more weight on
    RSAWeight, CPID, and TimeBlockFrom for more randomness.
  + Grandfathered in til 118977
* Sun Jan 18 2015 marix@marix.org
- Update to version 3.3.7.0
  + Mandatory Upgrade
  + Fixed Nonce Problem & Zero mint issue
  + Grandfather til 118834
* Sun Jan 18 2015 marix@marix.org
- Update to version 3.3.6.8
  + Mandatory Upgrade
  + MintLimiter checks for tiny blocks in CheckBlock (some tiny
    blocks getting through by being forwarded as orphans) and
    possibly orphaning POR blocks
  + 16 hour minimum coin age maturity (increased from 8 hour) -
    Reduce  orphans
  + POW Diff 25%% harder - Reduce orphans
  + POR Subsidy Creation verifies block limit is not breached (In
    response to 8 errors in the logs where a CPID was trying to
    submit a block for 2*block max); Plus GetProofOfResearchReward
    now does a hard chain check
  + Grandfather til 118821
* Sat Jan 17 2015 marix@marix.org
- Update to version 3.3.6.7
  + Mandatory Upgrade
  + Nonce problem fixed
  + Grandfather til 118050
  + RSA simplified: Key indicators: Daily Owed, Daily Paid
  + Hard Chain POR approval system implemented: If POR Daily Paid
    will exceed Daily Owed, Block is rejected (newbies receive a
    first block credit). Should help prevent any orphans/forks.
  + Added command: execute chainrsa cpid.  This allows me to test
    any cpid in the list magnitudecsv report to verify the hard
    chain system is working : SUCCESS
  + Added attachments to Tickets (Note: do not open an attachment
    from an untrusted sender.).
* Sat Jan 17 2015 marix@marix.org
- Update to version 3.3.6.4
  + Leisure Upgrade
  + No auto ban for timedrift orphan blocks; but blocks are still
    rejected
* Fri Jan 16 2015 marix@marix.org
- Update to version 3.3.6.2
  + Mandatory Upgrade
  + Starts @ 117400
  + Added timedrift checks to orphans
  + Added PoW for investors + researchers
  + disabled CPID submission time window in favor of stronger
    block submission window checks
  + Clients must submit blocks within 10 minutes of the avg network
    time - checking past drift and future drift (currently stake
    2.0 only checks future drift)
* Fri Jan 16 2015 marix@marix.org
- Update to version 3.3.6.0
  + Mandatory Upgrade
  + Starts @ 116862
  + CPIDs submitting POR blocks will submit during a 30 minute time
    window.
  + Interest blocks are still submitted around the clock.
  + To find out your time window, do a list rsa - look for
    Registered Payment Time
* Wed Jan 14 2015 marix@marix.org
- Update to version 3.3.5.9
  + Mandatory Upgrade
  + Limit block submissions to one submission per 5 minutes across
    nodes
  + Fixed Right click on Tickets; Fixed assigned to; Fixed List
  + Fixed sync from zero regarding non-grandfathered erroring
    blocks
  + Set suppressreboot=false by default
* Wed Jan 14 2015 marix@marix.org
- Update to version 3.3.5.8
  + Mandatory Upgrade
  + Reset Diff automatically after it cycles over 900,000 (anytime)
  + Allow PoR blocks to stake even with high diff (with a cap of 1
    day max age)
  + Starts @ 115765
  + Tickets Beta (more explanation coming)
* Wed Jan 14 2015 marix@marix.org
- Update to version 3.3.5.7
  + Mandatory Upgrade
  + Added DoS rule in block acceptor
  + Increased POR local difficulty by 50%% and decreased remote diff (orphans)
  + Starts @ 115237
* Tue Jan 13 2015 marix@marix.org
- Update to version 3.3.5.5
  + Mandatory Upgrade
  + DOS or Ban submitter of bad cpid blocks
  + Ban submitters resulting in RSA account balance < 0 - and
    retally
  + during block rejection (orphans)
  + Added RSA Weight to target stake hash
  + Removed some logging
  + Modified kernel solution to be 50%% harder in-client therefore
    50%% easier during remote block check (in hopes to eliminate the
    orphans)
  + Starts @ 114792
* Mon Jan 12 2015 marix@marix.org
- Patch the source to not use the window icon from Novacoin
* Mon Jan 12 2015 marix@marix.org
- Update to version 3.3.5.4
  + Mandatory Upgrade
  + Control Runaway Difficulty (Starts @114175)
* Sun Jan 11 2015 marix@marix.org
- Update to version 3.3.5.3
  + Leisure Upgrade
  + Fixed retally problem during reorganizations
* Sun Jan 11 2015 marix@marix.org
- Update to version 3.3.5.2
  + Mandatory Upgrade
  + 90 Second block targets
  + 1000 block lookback in Tally Network Averages
  + Removed PoW
  + Consolidated PoR RSA_WEIGHT into PoS2.0 Algorithm for the new
    homogenized PoR algorithm
  + Added linux support
  + Added Org messages to every decrypted message in the coin in the log,
    to allow banning misbehaving nodes
  + Restored ability to self compile using the last set of keys that I
    PM'ed : NOTE * Any user who wants to self-compile must PM me for a key.
  + New rules start @ 113836
* Sat Jan 10 2015 marix@marix.org
- Update to version 3.3.4.7
  + Mandatory Upgrade
  + PoW is now based on last payment time and block difficulty
  + Added PoW mining to Investors Added PoW mining to Investors
  + Added PoW nonce indicator to overview page
  + Removed logging
* Fri Jan  9 2015 marix@marix.org
- Update to version 3.3.4.6
  + Leisure Upgrade
  + Fixed Orphan mask (showorphans=true)
  + Added ability to restake if wallet orphans
* Thu Jan  8 2015 marix@marix.org
- Update to version 3.3.4.5
  + Leisure Upgrade
  + Added an option to show orphans: showorphans
* Wed Jan  7 2015 marix@marix.org
- Update to version 3.3.4.2
  + Mandatory upgrade
  + Easier staking for newbies
  + Improved staking issue analytics
* Wed Jan  7 2015 marix@marix.org
- Update to version 3.3.4.1
  + Mandatory upgrade
  + Newbies get an additional GRC on first block
  + Fixes crash on keysigning
* Tue Jan  6 2015 marix@marix.org
- Update to version 3.3.4.0
  + Mandatory upgrade
  + Staking improved on slow machines
  + Only require 10 GRC to stake the first block
* Tue Jan  6 2015 marix@marix.org
- Update to version 3.3.3.8
  + Leisure Upgrade
  + Four new BOINC projects added:
  * ibercivis
  * iGEM@home
  * primaboinca
  * wanless2
  + New RPC command for debugging: currenttime
* Sun Jan  4 2015 marix@marix.org
- Update to version 3.3.3.7
  + Leisure Upgrade
  + Improved staking issue analytics
* Sun Jan  4 2015 marix@marix.org
- Update to version 3.3.3.6
  + Leisure Upgrade
  + Improved statistics on staking
  + Improved log output on staking if configuration option debug3
    is set to true.
* Sat Jan  3 2015 marix@marix.org
- Use distribution-specified compliation flags
* Sat Jan  3 2015 marix@marix.org
- Update to version 3.3.3.3
  + Leisure Upgrade
  + There is now an optional live ticker showing stock and crypto
    prices.
- Fixed RPM build on Fedora, which got broken by the introduction
  of the desktop file.
* Sat Jan  3 2015 marix@marix.org
- Added a desktop file for gridcoinresearch-qt
* Sat Jan  3 2015 marix@marix.org
- Update to version 3.3.3.3
  + Leisure Upgrade
  + New configuration option: punishment. This option allows to
    customize the ban duration.
  + New configuration option: orphanpunishment. Set it to zero on
    if you do not want to punish hackers for forwarding orphans
    through you (allows you to sync).
* Fri Jan  2 2015 marix@marix.org
- Added support for building on Fedora
* Fri Jan  2 2015 marix@marix.org
- Enable QR code support in gridcoinresearch-qt
* Fri Jan  2 2015 marix@marix.org
- Added gridcoinresearch-qt providing the end-user GUI
  + Does not support QR codes, yet
* Fri Jan  2 2015 marix@marix.org
- Update to version 3.3.3.0
  + Mandatory upgrade
  + More efficient POW
- Enabled UPNP support in the binary
  + Based on a patch that has also been commited upstream
* Fri Jan  2 2015 marix@marix.org
- Update to version 3.3.2.8.1
  + Mandatory upgrade
* Thu Jan  1 2015 marix@marix.org
- Update to version 3.3.2.7-150
* Thu Jan  1 2015 marix@marix.org
- Update to version 3.3.2.7-145
  + Fix UI lag problems
* Thu Jan  1 2015 marix@marix.org
- Update to version 3.3.2.7
  + Fixed mixed case email->CPID issue
  + Fixed new user wizard bug
  + Refinements to prevent orphans
* Thu Jan  1 2015 marix@marix.org
- Update to version 3.3.2.6-130
* Thu Jan  1 2015 marix@marix.org
- Updated to version 3.3.2.6.3
- Download source via file download service
* Wed Dec 31 2014 marix@marix.org
- Adjusted spec file name to match built package
* Wed Dec 31 2014 marix@marix.org
- Fix build on openSUSE 13.2 x86_64 which fails because it runs out
  of memory
* Wed Dec 31 2014 marix@marix.org
- Updated to version 3.3.2.2
  + Fixed CPID payment span issue
* Tue Dec 30 2014 marix@marix.org
- Version 3.3.2.1
- Initial release of this package
  + Only headless binary, no qt version, yet
  + Still needs better handling of source and versions
